package Google::Cloud::SQL::V1::SqlInstanceNamesServiceClient;

use strict;
use warnings;

use Protobuf;
use Google::Api::Common;
use Google::Cloud::Sql::V1::CloudSqlResources;
use Google::Cloud::Sql::V1::CloudSqlAvailableDatabaseVersions;
use Google::Cloud::Sql::V1::CloudSqlIamPolicies;
use Google::Cloud::Sql::V1::CloudSqlEvents;
use Google::Cloud::Sql::V1::CloudSqlRegions;
use Google::Cloud::Sql::V1::CloudSqlFeatureEligibility;
use Google::Cloud::Sql::V1::CloudSqlInstanceNames;
use Google::Cloud::Sql::V1::CloudSqlTiers;
use Google::Cloud::Sql::V1::CloudSqlSslCerts;
use Google::Cloud::Sql::V1::CloudSqlInstances;
use Google::Cloud::Sql::V1::CloudSqlUsers;
use Google::Cloud::Sql::V1::CloudSqlBackupRuns;
use Google::Cloud::Sql::V1::CloudSqlOperations;
use Google::Cloud::Sql::V1::CloudSqlFlags;
use Google::Cloud::Sql::V1::CloudSqlDatabases;
use Google::Cloud::Sql::V1::CloudSqlConnect;
use Google::Cloud::Sql::V1::CloudSqlBackups;

our $VERSION = '0.02';
1; # End of Google::Cloud::SQL::V1::SqlInstanceNamesServiceClient

__END__

=head1 NAME

Google::Cloud::SQL::V1::SqlInstanceNamesServiceClient - Auto-generated Protocol Buffers schema container

=head1 DESCRIPTION

This is an auto-generated Protocol Buffers schema container module for Google Cloud Services.

=head1 SOURCE

Generated from the following Protocol Buffers schemas:

=over 4

=item * C<google/cloud/sql/v1/cloud_sql_feature_eligibility.proto>

=item * C<google/cloud/sql/v1/cloud_sql_iam_policies.proto>

=item * C<google/cloud/sql/v1/cloud_sql_backup_runs.proto>

=item * C<google/cloud/sql/v1/cloud_sql_available_database_versions.proto>

=item * C<google/cloud/sql/v1/cloud_sql_databases.proto>

=item * C<google/cloud/sql/v1/cloud_sql_tiers.proto>

=item * C<google/cloud/sql/v1/cloud_sql_regions.proto>

=item * C<google/cloud/sql/v1/cloud_sql_ssl_certs.proto>

=item * C<google/cloud/sql/v1/cloud_sql_resources.proto>

=item * C<google/cloud/sql/v1/cloud_sql_instance_names.proto>

=item * C<google/cloud/sql/v1/cloud_sql_instances.proto>

=item * C<google/cloud/sql/v1/cloud_sql_operations.proto>

=item * C<google/cloud/sql/v1/cloud_sql_users.proto>

=item * C<google/cloud/sql/v1/cloud_sql_flags.proto>

=item * C<google/cloud/sql/v1/cloud_sql_backups.proto>

=item * C<google/cloud/sql/v1/cloud_sql_connect.proto>

=item * C<google/cloud/sql/v1/cloud_sql_events.proto>



=back

=head1 LICENSE AND COPYRIGHT

Copyright (C) 2026 Google LLC

This program is released under the Apache 2.0 license.

=cut
