package Google::Cloud::Sql::V1::CloudSqlOperations;

use strict;
use warnings;

our $VERSION = '0.11';

use Protobuf::Message;
use Protobuf::DescriptorPool;
use Protobuf::Internal qw(:all);
use MIME::Base64;

BEGIN {
    eval { require Google::Api::Annotations };
    eval { require Google::Api::Client };
    eval { require Google::Api::FieldBehavior };
    eval { require Google::Cloud::Sql::V1::CloudSqlResources };
    eval { require Google::Protobuf::Empty };
    my $descriptor_b64 = <<'EOF';

nAgAEgNwFz1iBnByb3RvMw==
EOF
    Protobuf::DescriptorPool->generated_pool->add_serialized_file(MIME::Base64::decode_base64($descriptor_b64));
}

# Message definitions

# === Message: Google::Cloud::Sql::V1::CloudSqlOperations::SqlOperationsGetRequest ===
    # Fields for SqlOperationsGetRequest
    # Field: operation Type: 9 ()
    # Field: project Type: 9 ()
    # Field: location Type: 9 ()

=pod

=head1 NAME

Google::Cloud::Sql::V1::CloudSqlOperations::SqlOperationsGetRequest - Compiled Protocol Buffers message class

=head1 SYNOPSIS

    use Google::Cloud::Sql::V1::CloudSqlOperations;

    my $msg = Google::Cloud::Sql::V1::CloudSqlOperations::SqlOperationsGetRequest->new(
        operation => $value,
    );

=head1 FIELDS

=over 4

=item * B<operation>

Type: String

=item * B<project>

Type: String

=item * B<location>

Type: String

=back

=cut

# === Message: Google::Cloud::Sql::V1::CloudSqlOperations::SqlOperationsListRequest ===
    # Fields for SqlOperationsListRequest
    # Field: instance Type: 9 ()
    # Field: max_results Type: 13 ()
    # Field: page_token Type: 9 ()
    # Field: project Type: 9 ()
    # Field: location Type: 9 ()

=pod

=head1 NAME

Google::Cloud::Sql::V1::CloudSqlOperations::SqlOperationsListRequest - Compiled Protocol Buffers message class

=head1 SYNOPSIS

    use Google::Cloud::Sql::V1::CloudSqlOperations;

    my $msg = Google::Cloud::Sql::V1::CloudSqlOperations::SqlOperationsListRequest->new(
        instance => $value,
    );

=head1 FIELDS

=over 4

=item * B<instance>

Type: String

=item * B<max_results>

Type: UInt32

=item * B<page_token>

Type: String

=item * B<project>

Type: String

=item * B<location>

Type: String

=back

=cut

# === Message: Google::Cloud::Sql::V1::CloudSqlOperations::OperationsListResponse ===
    # Fields for OperationsListResponse
    # Field: kind Type: 9 ()
    # Field: items Type: 11 (.google.cloud.sql.v1.Operation)
    # Field: next_page_token Type: 9 ()

=pod

=head1 NAME

Google::Cloud::Sql::V1::CloudSqlOperations::OperationsListResponse - Compiled Protocol Buffers message class

=head1 SYNOPSIS

    use Google::Cloud::Sql::V1::CloudSqlOperations;

    my $msg = Google::Cloud::Sql::V1::CloudSqlOperations::OperationsListResponse->new(
        kind => $value,
    );

=head1 FIELDS

=over 4

=item * B<kind>

Type: String

=item * B<items>

Type: Message (.google.cloud.sql.v1.Operation)

=item * B<next_page_token>

Type: String

=back

=cut

# === Message: Google::Cloud::Sql::V1::CloudSqlOperations::SqlOperationsCancelRequest ===
    # Fields for SqlOperationsCancelRequest
    # Field: operation Type: 9 ()
    # Field: project Type: 9 ()
    # Field: location Type: 9 ()

=pod

=head1 NAME

Google::Cloud::Sql::V1::CloudSqlOperations::SqlOperationsCancelRequest - Compiled Protocol Buffers message class

=head1 SYNOPSIS

    use Google::Cloud::Sql::V1::CloudSqlOperations;

    my $msg = Google::Cloud::Sql::V1::CloudSqlOperations::SqlOperationsCancelRequest->new(
        operation => $value,
    );

=head1 FIELDS

=over 4

=item * B<operation>

Type: String

=item * B<project>

Type: String

=item * B<location>

Type: String

=back

=cut

# === Service Client: Google::Cloud::Sql::V1::CloudSqlOperations::SqlOperationsServiceClient ===
package Google::Cloud::Sql::V1::CloudSqlOperations::SqlOperationsServiceClient;

=pod

=head1 NAME

Google::Cloud::Sql::V1::CloudSqlOperations::SqlOperationsServiceClient - Client stub representing the remote SqlOperationsService service

=head1 DESCRIPTION

This class acts as a local client stub for the remote gRPC service.
It delegates call dispatching to an underlying L<Google::gRPC::Client>
instance, ensuring type-safe request parsing and response mapping.

=head1 CONFIGURATION AND ENVIRONMENT

=head2 target

The endpoint target address. Defaults to C<sql.googleapis.com:443>.

=head2 credentials

The authentication credentials provider. Defaults to application default credentials via L<Google::Auth>.

=cut

use Moo;
use Google::Auth;
use Google::gRPC::Client;

has credentials => ( is => 'ro', default => sub { Google::Auth->default() } );
has target      => ( is => 'ro', default => 'sql.googleapis.com:443' );

has _grpc_client => (
    is => 'ro',
    lazy => 1,
    builder => sub {
        my $self = shift;
        return Google::gRPC::Client->new(
            target     => $self->target,
            auth_token => $self->credentials->get_token(),
        );
    }
);

sub get {
    my ($self, $args) = @_;
    my $req = ref($args) eq 'HASH'
        ? Google::Cloud::Sql::V1::CloudSqlOperations::SqlOperationsGetRequest->new($args)
        : $args;
    return $self->_grpc_client->call({
        service        => 'google.cloud.sql.v1.SqlOperationsService',
        method         => 'Get',
        request        => $req,
        response_class => 'Google::Cloud::Sql::V1::CloudSqlResources::Operation',
    });
}

sub list {
    my ($self, $args) = @_;
    my $req = ref($args) eq 'HASH'
        ? Google::Cloud::Sql::V1::CloudSqlOperations::SqlOperationsListRequest->new($args)
        : $args;
    return $self->_grpc_client->call({
        service        => 'google.cloud.sql.v1.SqlOperationsService',
        method         => 'List',
        request        => $req,
        response_class => 'Google::Cloud::Sql::V1::CloudSqlOperations::OperationsListResponse',
    });
}

sub cancel {
    my ($self, $args) = @_;
    my $req = ref($args) eq 'HASH'
        ? Google::Cloud::Sql::V1::CloudSqlOperations::SqlOperationsCancelRequest->new($args)
        : $args;
    return $self->_grpc_client->call({
        service        => 'google.cloud.sql.v1.SqlOperationsService',
        method         => 'Cancel',
        request        => $req,
        response_class => 'Google::Protobuf::Empty::Empty',
    });
}

1;

__END__

=head1 NAME

Google::Cloud::Sql::V1::CloudSqlOperations - Protocol Buffers schema definition

=head1 DESCRIPTION

Auto-generated Protocol Buffers schema definition class.

=head1 LICENSE AND COPYRIGHT

Copyright (C) 2026 Google LLC

This program is released under the Apache 2.0 license.

=cut
